portmonitor_fix_reply_handler {#master}
-----------------------------

## Carriers

### `portmonitor`

* The reply handler is now set correctly, it is therefore now possible to
  monitor RPC connections.
